pub struct GroupMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on group resources.
It is not used directly, but through the CloudUserAccounts hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_clouduseraccountsvm_beta as clouduseraccountsvm_beta;
use clouduseraccountsvm_beta::{CloudUserAccounts, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudUserAccounts::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `add_member(...)`, `delete(...)`, `get(...)`, `insert(...)`, `list(...)` and `remove_member(...)`
// to build up your call.
let rb = hub.groups();Implementations
Sourceimpl<'a, C> GroupMethods<'a, C>
impl<'a, C> GroupMethods<'a, C>
Sourcepub fn add_member(
&self,
request: GroupsAddMemberRequest,
project: &str,
group_name: &str,
) -> GroupAddMemberCall<'a, C>
pub fn add_member( &self, request: GroupsAddMemberRequest, project: &str, group_name: &str, ) -> GroupAddMemberCall<'a, C>
Create a builder to help you perform the following task:
Adds users to the specified group.
Arguments
request- No description provided.project- Project ID for this request.groupName- Name of the group for this request.
Sourcepub fn delete(&self, project: &str, group_name: &str) -> GroupDeleteCall<'a, C>
pub fn delete(&self, project: &str, group_name: &str) -> GroupDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes the specified Group resource.
Arguments
project- Project ID for this request.groupName- Name of the Group resource to delete.
Sourcepub fn get(&self, project: &str, group_name: &str) -> GroupGetCall<'a, C>
pub fn get(&self, project: &str, group_name: &str) -> GroupGetCall<'a, C>
Create a builder to help you perform the following task:
Returns the specified Group resource.
Arguments
project- Project ID for this request.groupName- Name of the Group resource to return.
Sourcepub fn insert(&self, request: Group, project: &str) -> GroupInsertCall<'a, C>
pub fn insert(&self, request: Group, project: &str) -> GroupInsertCall<'a, C>
Create a builder to help you perform the following task:
Creates a Group resource in the specified project using the data included in the request.
Arguments
request- No description provided.project- Project ID for this request.
Sourcepub fn list(&self, project: &str) -> GroupListCall<'a, C>
pub fn list(&self, project: &str) -> GroupListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves the list of groups contained within the specified project.
Arguments
project- Project ID for this request.
Sourcepub fn remove_member(
&self,
request: GroupsRemoveMemberRequest,
project: &str,
group_name: &str,
) -> GroupRemoveMemberCall<'a, C>
pub fn remove_member( &self, request: GroupsRemoveMemberRequest, project: &str, group_name: &str, ) -> GroupRemoveMemberCall<'a, C>
Create a builder to help you perform the following task:
Removes users from the specified group.
Arguments
request- No description provided.project- Project ID for this request.groupName- Name of the group for this request.