pub struct UserMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on user resources.
It is not used directly, but through the CloudUserAccounts hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_clouduseraccountsvm_beta as clouduseraccountsvm_beta;
use clouduseraccountsvm_beta::{CloudUserAccounts, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudUserAccounts::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `add_public_key(...)`, `delete(...)`, `get(...)`, `insert(...)`, `list(...)` and `remove_public_key(...)`
// to build up your call.
let rb = hub.users();Implementations
Sourceimpl<'a, C> UserMethods<'a, C>
impl<'a, C> UserMethods<'a, C>
Sourcepub fn add_public_key(
&self,
request: PublicKey,
project: &str,
user: &str,
) -> UserAddPublicKeyCall<'a, C>
pub fn add_public_key( &self, request: PublicKey, project: &str, user: &str, ) -> UserAddPublicKeyCall<'a, C>
Create a builder to help you perform the following task:
Adds a public key to the specified User resource with the data included in the request.
Arguments
request- No description provided.project- Project ID for this request.user- Name of the user for this request.
Sourcepub fn delete(&self, project: &str, user: &str) -> UserDeleteCall<'a, C>
pub fn delete(&self, project: &str, user: &str) -> UserDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes the specified User resource.
Arguments
project- Project ID for this request.user- Name of the user resource to delete.
Sourcepub fn get(&self, project: &str, user: &str) -> UserGetCall<'a, C>
pub fn get(&self, project: &str, user: &str) -> UserGetCall<'a, C>
Create a builder to help you perform the following task:
Returns the specified User resource.
Arguments
project- Project ID for this request.user- Name of the user resource to return.
Sourcepub fn insert(&self, request: User, project: &str) -> UserInsertCall<'a, C>
pub fn insert(&self, request: User, project: &str) -> UserInsertCall<'a, C>
Create a builder to help you perform the following task:
Creates a User resource in the specified project using the data included in the request.
Arguments
request- No description provided.project- Project ID for this request.
Sourcepub fn list(&self, project: &str) -> UserListCall<'a, C>
pub fn list(&self, project: &str) -> UserListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of users contained within the specified project.
Arguments
project- Project ID for this request.
Sourcepub fn remove_public_key(
&self,
project: &str,
user: &str,
fingerprint: &str,
) -> UserRemovePublicKeyCall<'a, C>
pub fn remove_public_key( &self, project: &str, user: &str, fingerprint: &str, ) -> UserRemovePublicKeyCall<'a, C>
Create a builder to help you perform the following task:
Removes the specified public key from the user.
Arguments
project- Project ID for this request.user- Name of the user for this request.fingerprint- The fingerprint of the public key to delete. Public keys are identified by their fingerprint, which is defined by RFC4716 to be the MD5 digest of the public key.